# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.6] - 2025-02-25
### Added
- `--calendar` argument
### Changed
- `README.md` updated
## [0.5] - 2025-02-14
### Added
- `--hide-date` argument
- `--hide-timezone` argument
- `--am-pm` argument
### Changed
- `README.md` updated
## [0.4] - 2025-01-18
### Added
- Date
- `--info` argument
## [0.3] - 2025-01-10
### Added
- Logo
- `--vertical` argument
### Changed
- `show_faces_list` function updated
- `AUTHORS.md` updated
## [0.2] - 2025-01-01
### Added
- Blink mode
- `--no-blink` argument
### Changed
- `README.md` updated
## [0.1] - 2024-12-24
### Added
- `--v-shift` and `--h-shift` arguments
- `--timezone` argument
- `--face` argument
- `run_clock` and `main` functions
- `TIMEZONES.md`
- `FACES.md`

[Unreleased]: https://github.com/sepandhaghighi/clox/compare/v0.6...dev
[0.6]: https://github.com/sepandhaghighi/clox/compare/v0.5...v0.6
[0.5]: https://github.com/sepandhaghighi/clox/compare/v0.4...v0.5
[0.4]: https://github.com/sepandhaghighi/clox/compare/v0.3...v0.4
[0.3]: https://github.com/sepandhaghighi/clox/compare/v0.2...v0.3
[0.2]: https://github.com/sepandhaghighi/clox/compare/v0.1...v0.2
[0.1]: https://github.com/sepandhaghighi/clox/compare/e9b49e2...v0.1



